# <a name="POIM-PDU-Description"></a>ASN.1 module POIM-PDU-Description
OID: _{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) poi(103916) poim(0) major-version-1 (1) minor-version-1 (1)}_

## Imports:
* **[ETSI-ITS-CDD](ETSI-ITS-CDD.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (102894) cdd (2) major-version-4 (4) minor-version-1 (1)} WITH SUCCESSORS*<br/>
* **[POIM-ParkingAvailability](POIM-ParkingAvailability.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) poi(103916) parkingAvailability(1) major-version-1 (1) minor-version-1 (1)} WITH SUCCESSORS*<br/>
## Data Elements:
### <a name="POIM"></a>POIM
This type represents the POIM PDU.

 It shall include the following components:

* _header_ of type [**ItsPduHeader**](ETSI-ITS-CDD.md#ItsPduHeader)  (WITH COMPONENTS {... , protocolVersion (1), messageId(poim)})<br>
  the header of the POIM PDU.

* _payload_ of type [**WrappedPoiInformationBlocks**](#WrappedPoiInformationBlocks) <br>
  the payload of the POIM PDU.

```asn1
POIM ::= SEQUENCE { 
    header  	ItsPduHeader (WITH COMPONENTS {... , protocolVersion (1), messageId(poim)}),        
    payload     WrappedPoiInformationBlocks
}
```

### <a name="WrappedPoiInformationBlocks"></a>WrappedPoiInformationBlocks
This DF represents a list of POI information blocks, each with their type identifier.
```asn1
WrappedPoiInformationBlocks::= SEQUENCE (SIZE (1..8,...)) OF WrappedPoiInformationBlock
```

### <a name="BLOCK-TYPE"></a>BLOCK-TYPE
This information object class is an abstract template to instantiate POI Information Blocks.

 It shall include the following components:

* _id_ of type [**PoiType**](POIM-PDU-Description.md#PoiType) <br>
  the identifier of the block type.

* Type<br>
  the block content.

```asn1
BLOCK-TYPE ::= CLASS {
    &id        PoiType,
    &Content
} WITH SYNTAX {&Content IDENTIFIED BY &id}
```

### <a name="PoiType"></a>PoiType
This DE represents the identifier of the container type.
```asn1
PoiType::= INTEGER(1..128,...)
```

These value assignements represent specific values of the block type identifier.

```asn1
parkingAvailability    PoiType ::= 1
```

### <a name="PoiInformationSet"></a>PoiInformationSet
This information object set represents the association between the block type and the block content.
```asn1
PoiInformationSet BLOCK-TYPE ::= {
   {ParkingAvailabilityBlock    IDENTIFIED BY parkingAvailability}, ...
}
```

### <a name="WrappedPoiInformationBlock"></a>WrappedPoiInformationBlock
This DF represents a POI Information Block preceded by its type identifier and a lenght indicator.

 It shall include the following components:

* _poiType_ of type [**BLOCK-TYPE**](#BLOCK-TYPE) .&id({PoiInformationSet})<br>
  the identifier of the POI Information Block type.

* _poiBlock_ of type [**BLOCK-TYPE**](#BLOCK-TYPE) .&Content({PoiInformationSet}{@poiType})<br>
  the POI Information Block.

```asn1
WrappedPoiInformationBlock ::= SEQUENCE {
    poiType      BLOCK-TYPE.&id({PoiInformationSet}),
    poiBlock     BLOCK-TYPE.&Content({PoiInformationSet}{@poiType})
}
```



