# <a name="POIM-ParkingAvailability"></a>ASN.1 module POIM-ParkingAvailability
OID: _{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) poi(103916) parkingAvailability(1) major-version-1 (1) minor-version-1 (1)}_

## Imports:
* **[ETSI-ITS-CDD](ETSI-ITS-CDD.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (102894) cdd (2) major-version-4 (4) minor-version-1 (1)} WITH SUCCESSORS*<br/>
* **[POIM-CommonContainers](POIM-CommonContainers.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) poi(103916) common(99) major-version-1 (1) minor-version-1 (1)} WITH SUCCESSORS*<br/>
* **[EfcDataDictionary](EfcDataDictionary.md)** *{iso(1) standard(0) 17573 dd(3) version1(1) minorVersion3(3)} WITH SUCCESSORS*<br/>
## Data Elements:
### <a name="ParkingAvailabilityBlock"></a>ParkingAvailabilityBlock
This type represents the POI Information Block concerning a parking availability at a given facility.  

 It shall include the following components:

* _managementContainer_ of type [**PoiBlockManagementContainer**](POIM-CommonContainers.md#PoiBlockManagementContainer) <br>
  the management container of the parking availability POI Information Block.

* _placeInfo_ of type [**GeneralParkingPlaceContainer**](#GeneralParkingPlaceContainer) <br>
  general information about the parking facility.

* _aggregatedstatus_ of type [**ParkingStatusContainer**](#ParkingStatusContainer) <br>
  aggregated status information about the parking facility.

* _detailedstatus_ of type [**ParkingSupplyCapabilitiesContainer**](#ParkingSupplyCapabilitiesContainer)  OPTIONAL<br>
  detailed topology and status information about the parking areas and spaces.

* _relatedPoi_ of type [**RelatedPoiInfoBlockContainer**](POIM-CommonContainers.md#RelatedPoiInfoBlockContainer)  OPTIONAL<br>
  reference to other relevant POI Information Blocks.  

```asn1
ParkingAvailabilityBlock::= SEQUENCE{
   managementContainer     PoiBlockManagementContainer,
   placeInfo               GeneralParkingPlaceContainer,
   aggregatedstatus        ParkingStatusContainer,
   detailedstatus          ParkingSupplyCapabilitiesContainer OPTIONAL,
   relatedPoi              RelatedPoiInfoBlockContainer OPTIONAL,
   ...
}
```

### <a name="GeneralParkingPlaceContainer"></a>GeneralParkingPlaceContainer
This type represents the General Parking Facility Container.

 It shall include the following components:

* _position_ of type [**GeoPosition**](#GeoPosition) <br>
  the position of the parking facility.

* _name_ of type [**UTF8String**](#UTF8String)  (SIZE (1..31))<br>
  the name of the parking facility.

* _openingPeriods_ of type [**Periods**](#Periods)  OPTIONAL<br>
  the optional opening periods of the parking facility.

* _address_ of type [**UTF8String**](#UTF8String)  (SIZE (1..255)) OPTIONAL<br>
  the address of the parking facility.

* _phoneNumber_ of type [**UTF8String**](#UTF8String)  (SIZE (1..31)) OPTIONAL<br>
  the phone number of the operator of the parking facility. 

* _website_ of type [**UTF8String**](#UTF8String)  (SIZE (1..31)) OPTIONAL<br>
  the URL of the website of the operator of the parking facility.

```asn1
GeneralParkingPlaceContainer::= SEQUENCE{
   position              GeoPosition,
   name 		         UTF8String (SIZE (1..31)),
   openingPeriods    	 Periods OPTIONAL,
   address 		         UTF8String (SIZE (1..255)) OPTIONAL,
   phoneNumber 	         UTF8String (SIZE (1..31)) OPTIONAL,
   website               UTF8String (SIZE (1..31)) OPTIONAL,
   ...
}
```

### <a name="ParkingStatusContainer"></a>ParkingStatusContainer
This type represents the Parking Status Container.

 It shall include the following components:

* _currentFacilityStatus_ of type [**OpeningStatus**](#OpeningStatus) <br>
  the current status of the facility.

* _currentOccupancy_ of type [**OccupancyInformation**](#OccupancyInformation)  OPTIONAL<br>
  the optional current occupancy of the entire facility.
   This component is only representative if the entire facility has areas and spaces of the same type. e.g. personal car parking spaces only. 

* _detailedStatus_ of type [**ParkingStatusList**](#ParkingStatusList)  OPTIONAL<br>
  the optional detailed parking availability status of the facility.

```asn1
ParkingStatusContainer::= SEQUENCE {
	currentFacilityStatus    OpeningStatus,
    currentOccupancy         OccupancyInformation OPTIONAL,           
	detailedStatus           ParkingStatusList OPTIONAL,
    ...
}
```

### <a name="ParkingSupplyCapabilitiesContainer"></a>ParkingSupplyCapabilitiesContainer
This type represents the ParkingSupplyCapabilitiesContainer and is a list of [**ParkingAreas**](#ParkingAreas).
```asn1
ParkingSupplyCapabilitiesContainer::= SEQUENCE OF ParkingAreas
```

### <a name="DeltaPosition"></a>DeltaPosition
This DF indicates a geographical position with reference to a reference position.

 It shall include the following components:

* _deltaLatitude_ of type [**DeltaLatitude**](ETSI-ITS-CDD.md#DeltaLatitude) <br>
  the delta latitude of the geographical position.

* _deltaLongitude_ of type [**DeltaLongitude**](ETSI-ITS-CDD.md#DeltaLongitude) <br>
  the delta longitude of the geographical position.

```asn1
DeltaPosition::=SEQUENCE{
	deltaLatitude 		DeltaLatitude,
	deltaLongitude		DeltaLongitude
	}
```

### <a name="DeltaPositions"></a>DeltaPositions
This DF shall contain an an ordered sequence of [**DeltaPosition**](#DeltaPosition) with respect to the previous position 
 with the first instance referring to a reference position and with the order implicitly defining a direction.
```asn1
DeltaPositions::= SEQUENCE (SIZE (1..32, ...))  OF DeltaPosition
```

### <a name="GeoPosition"></a>GeoPosition
This DF indicates a geographical position.

 It shall include the following components:

* _latitude_ of type [**Latitude**](ETSI-ITS-CDD.md#Latitude) <br>
  the latitude of the geographical position.

* _longitude_ of type [**Longitude**](ETSI-ITS-CDD.md#Longitude) <br>
  the longitude of the geographical position.

* _altitude_ of type [**AltitudeValue**](ETSI-ITS-CDD.md#AltitudeValue)  DEFAULT unavailable<br>
  the altitude of the geographical position.

```asn1
GeoPosition::= SEQUENCE{
	latitude  Latitude,
	longitude Longitude,
    altitude  AltitudeValue DEFAULT unavailable
	}
```

### <a name="LoadType"></a>LoadType
This DF indicates a the load type of the vehicle.

 It shall include the following components:

* _goodsType_ of type [**GoodsType**](#GoodsType)  OPTIONAL<br>
  optional information about the goods being transported.

* _dangerousGoodsType_ of type [**DangerousGoodsBasic**](ETSI-ITS-CDD.md#DangerousGoodsBasic)  OPTIONAL<br>
  the optional type of dangerous goods according to the European Agreement concerning the International Carriage of Dangerous Goods by Road (ADR). 

* _specialTransportType_ of type [**SpecialTransportType**](ETSI-ITS-CDD.md#SpecialTransportType) <br>
  the type of special transport according to local regulations.

```asn1
LoadType::= SEQUENCE{
	goodsType				GoodsType OPTIONAL,
	dangerousGoodsType		DangerousGoodsBasic OPTIONAL,
	specialTransportType	SpecialTransportType,
    ...
	}
```

### <a name="OccupancyInformation"></a>OccupancyInformation
This DF represents occupancy information. 

 It shall include the following components:

* _rate_ of type [**OccupancyRate**](#OccupancyRate) <br>
  the current occupancy in percentage, nominally = ((totalSpaces-freeSpaces)/totalSpaces) * 100.

* _trend_ of type [**OccupancyTrend**](#OccupancyTrend) <br>
  the current trend of the occupancy.

* _freeSpaces_ of type [**NumberOfSpaces**](#NumberOfSpaces) <br>
  the optional number of spaces that are actually available.

* _totalSpaces_ of type [**NumberOfSpaces**](#NumberOfSpaces) <br>
  the total number of spaces.

* _confidence_ of type [**ConfidenceLevel**](ETSI-ITS-CDD.md#ConfidenceLevel) <br>
  the confidence level of the above information.

```asn1
OccupancyInformation::= SEQUENCE{
   rate            OccupancyRate,
   trend           OccupancyTrend, 
   freeSpaces      NumberOfSpaces,
   totalSpaces	   NumberOfSpaces,
   confidence      ConfidenceLevel,
   ...
}
```

### <a name="ParkingArea"></a>ParkingArea
This DF provides information about the parking capabilities and availabilities of a parking identified area. 


 It shall include the following components:

* _id_ of type [**Identifier2B**](ETSI-ITS-CDD.md#Identifier2B) <br>
  the identifier of the parking area within the parking place/facility.

* _currentOccupancy_ of type [**OccupancyInformation**](#OccupancyInformation) <br>
  the current occupancy information of the parking area.

* _location_ of type [**GeoPosition**](#GeoPosition) <br>
  the location of the parking area.

* _level_ of type **INTEGER** (-8..16,...) DEFAULT 0<br>
  the level under/over ground floor of the parking area.

* _arrangementType_ of type [**ParkingAreaArrangementType**](#ParkingAreaArrangementType) <br>
  the common arrangement of the parking spaces within the area.
   the value ´mixed´ shall be used if there is no common arrangement. In this case the arrangement of the single spaces may be defined in the component spacesDetailed.

* _boundary_ of type [**DeltaPositions**](#DeltaPositions)  OPTIONAL<br>
  the optional physical boundary of the parking area as a polygon using the component location as reference position.

* _orientation_ of type [**Wgs84Angle**](ETSI-ITS-CDD.md#Wgs84Angle)  OPTIONAL<br>
  the optional common orientation of the parking spaces within the area.
   This is component shall be absent if there is no common orientation. In this case the orientation of the single spaces may be defined in the component spacesDetailed.

* _accessViaLane_ of type [**Identifier2B**](ETSI-ITS-CDD.md#Identifier2B)  OPTIONAL<br>
  the optional identifier of a lane that provides access to the parking area.

* _allowedVehicleCategories_ of type **SEQUENCE**  (SIZE(1..4,...)) OF EuVehicleCategoryCode<br>
  the categories of vehicles that are allowed in the parking area.

* _notAllowedEngineCharacteristics_ of type **SEQUENCE**  (SIZE(1..4,...)) OF EngineCharacteristics  OPTIONAL<br>
  the optional characteristic(s) of engines that are not allowed in the parking area.

* _allowedLoadTypes_ of type **SEQUENCE**  (SIZE(1..4,...)) OF LoadType OPTIONAL<br>
  the optional load type(s) that are allowed in the parking area.

* _notAllowedLoadTypes_ of type **SEQUENCE**  (SIZE(1..4,...)) OF LoadType OPTIONAL<br>
* _heightRestriction_ of type [**VehicleHeight**](ETSI-ITS-CDD.md#VehicleHeight)  OPTIONAL<br>
  the optional applicable vehicle height restriction.

* _reservationType_ of type **SEQUENCE**  (SIZE(1..4,...)) OF ParkingReservationType OPTIONAL<br>
  the optional parking reservation type(s) associated to the parking area.
   This is component shall be absent if there is no common reservation type. In this case the reservation type of the single spaces may be defined in the component spacesDetailed.

* _pricingInformation_ of type [**UTF8String**](#UTF8String)  OPTIONAL<br>
  the optional pricing information applicable to the parking area.

* _paymentInformation_ of type [**UTF8String**](#UTF8String)  OPTIONAL<br>
  the optional payment information applicable to the parking area.

* _bookingContactInfo_ of type [**UTF8String**](#UTF8String)  OPTIONAL<br>
  the optional booking contact information applicable to the parking area.

* _accessCharachteristics_ of type [**UTF8String**](#UTF8String)  OPTIONAL<br>
  the optional access information to the area.

* _freeSpacesPosition_ of type **SEQUENCE**  OF DeltaPosition OPTIONAL<br>
  the optional list of positions of free spaces.

* _freespacesId_ of type **SEQUENCE**  OF Identifier2B OPTIONAL<br>
  the optional list of Ids of free spaces.

* _spacesBasic_ of type [**ParkingSpacesBasic**](#ParkingSpacesBasic)  OPTIONAL<br>
  the optional basic information about none, some or all parking spaces within the area.

* _spacesDetailed_ of type [**ParkingSpacesDetailed**](#ParkingSpacesDetailed)  OPTIONAL<br>
  the optional detailed information about none, some or all parking spaces within the area.

* notallowedLoadTypes<br>
  the optional load type(s) that are not allowed in the parking area.


>>>
NOTE:&emsp;a parking area possibly groups all spaces with the same characteristics.
>>>

```asn1
ParkingArea::=SEQUENCE{
   id                                 Identifier2B,
   currentOccupancy                   OccupancyInformation, 
   location                           GeoPosition,
   level                              INTEGER(-8..16,...) DEFAULT 0,
   arrangementType                    ParkingAreaArrangementType,
   boundary                           DeltaPositions OPTIONAL, 
   orientation                        Wgs84Angle OPTIONAL, 
   accessViaLane			          Identifier2B OPTIONAL,
   allowedVehicleCategories           SEQUENCE (SIZE(1..4,...)) OF EuVehicleCategoryCode, 
   notAllowedEngineCharacteristics    SEQUENCE (SIZE(1..4,...)) OF EngineCharacteristics  OPTIONAL,
   allowedLoadTypes                   SEQUENCE (SIZE(1..4,...)) OF LoadType OPTIONAL, 
   notAllowedLoadTypes                SEQUENCE (SIZE(1..4,...)) OF LoadType OPTIONAL,
   heightRestriction                  VehicleHeight OPTIONAL,
   reservationType                    SEQUENCE (SIZE(1..4,...)) OF ParkingReservationType OPTIONAL,
   pricingInformation                 UTF8String OPTIONAL,
   paymentInformation                 UTF8String OPTIONAL, 
   bookingContactInfo                 UTF8String OPTIONAL, 
   accessCharachteristics             UTF8String OPTIONAL,
   freeSpacesPosition                 SEQUENCE OF DeltaPosition OPTIONAL,
   freespacesId                       SEQUENCE OF Identifier2B OPTIONAL,
   spacesBasic                        ParkingSpacesBasic OPTIONAL,
   spacesDetailed                     ParkingSpacesDetailed OPTIONAL,
   ...
}
```

### <a name="ParkingAreas"></a>ParkingAreas
This DF shall contain a list of [**ParkingArea**](#ParkingArea).
```asn1
ParkingAreas::= SEQUENCE OF ParkingArea
```

### <a name="ParkingOccupancyInfo"></a>ParkingOccupancyInfo
This DF indicates the allowed type of occupancy of a parking space/area in terms of time and/or usage.

 The following options are available:

* _unknown_ of type **NULL** <br>
  indicates that the allowed type of occupancy is unknown.

* _unlimitedOccupancy_ of type **NULL** <br>
  indicates that it can be occupied without limits.

* _onlyWhileCharging_ of type **NULL** <br>
  indicates that it can be occupied only while charging an electric vehicle.

* _limitedDuration_ of type **INTEGER** <br>
  indicates that it can be occupied for a limited and indicated duration in minutes.

* _onlyWhileCharginglimitedDuration_ of type **INTEGER** <br>
  indicates that it can be occupied only while charging an electric vehicle and only for a limited and indicated duration in minutes.

* _parkingAllowedUntil_ of type [**TimestampIts**](ETSI-ITS-CDD.md#TimestampIts) <br>
  indicates that it can be occupied only until an indicated moment in time.

* _forcedParkingUntil_ of type [**TimestampIts**](ETSI-ITS-CDD.md#TimestampIts) <br>
  indicates that it can be occupied and departure is possible only after an indicated moment in time.

```asn1
ParkingOccupancyInfo::= CHOICE { 
   unknown                              NULL, 
   unlimitedOccupancy                   NULL,
   onlyWhileCharging                    NULL,  
   limitedDuration                      INTEGER,  
   onlyWhileCharginglimitedDuration     INTEGER, 
   parkingAllowedUntil                  TimestampIts,
   forcedParkingUntil                   TimestampIts,
   ...
}
```

### <a name="ParkingSpaceBasic"></a>ParkingSpaceBasic
This DF provides basic information about the parking capabilities and availabilities of a single parking space. 

 It shall include the following components:

* _id_ of type [**Identifier2B**](ETSI-ITS-CDD.md#Identifier2B) <br>
  the unqiue identifier of the parking space within the parking area.

* _location_ of type [**DeltaReferencePosition**](ETSI-ITS-CDD.md#DeltaReferencePosition)  OPTIONAL<br>
  the optional location of the geometrical center of the parking space w.r.t. the location of the parking area.

* _status_ of type [**ParkingSpaceStatus**](#ParkingSpaceStatus) <br>
  the actual status of the parking space.

```asn1
ParkingSpaceBasic ::= SEQUENCE{
   id         Identifier2B,
   location   DeltaReferencePosition OPTIONAL, 
   status     ParkingSpaceStatus
}
```

### <a name="ParkingSpaceDetailed"></a>ParkingSpaceDetailed
This DF provides detailed information about the parking capabilities and availabilities of a single parking space. 
 
 It is an extension of [**ParkingSpaceBasic**](#ParkingSpaceBasic) and it shall additionally include the following additional components:

* _COMPONENTS_ of type [**OF**](#OF)             ParkingSpaceBasic<br>
* _arrangementType_ of type [**ParkingAreaArrangementType**](#ParkingAreaArrangementType)  OPTIONAL<br>
  the optional arrangement of the parking space w.r.t. other spaces.
   This is component, if present, overrides the common arrangementType defined in the [**ParkingArea**](#ParkingArea).

* _boundary_ of type [**DeltaPositions**](#DeltaPositions)  OPTIONAL<br>
  the optional physical boundary of the parking space as a polygon w.r.t. the location of the parking space.

* _orientation_ of type [**Wgs84Angle**](ETSI-ITS-CDD.md#Wgs84Angle)  OPTIONAL<br>
  the optional orientation of the parking space.
   This is component, if present, overrides the common orientation defined in the [**ParkingArea**](#ParkingArea).

* _occupancyRule_ of type [**ParkingOccupancyInfo**](#ParkingOccupancyInfo) <br>
  the occupancy rule applicable to the parking space.

* _chargingStationId_ of type [**Identifier2B**](ETSI-ITS-CDD.md#Identifier2B)  OPTIONAL<br>
  the optional identitfier of a charging station that serves the parking space.

* _accessViaLane_ of type [**Identifier2B**](ETSI-ITS-CDD.md#Identifier2B)  OPTIONAL<br>
  the optional identifier of a lane that provides access to the parking space.

* _accessViaParkingSpaces_ of type **SEQUENCE**  (SIZE(0..7)) OF Identifier2B OPTIONAL<br>
  the optional identifier(s) of a parking spaces that provide access to the parking space.

* _reservationType_ of type **SEQUENCE**  (SIZE(1..4,...)) OF ParkingReservationType OPTIONAL<br>
  the optional parking reservation type(s) associated to the parking space.
   This is component, if present, overrides the common reservationType defined in the [**ParkingArea**](#ParkingArea).

```asn1
ParkingSpaceDetailed ::= SEQUENCE{
   COMPONENTS OF            ParkingSpaceBasic,
   arrangementType          ParkingAreaArrangementType OPTIONAL,
   boundary                 DeltaPositions OPTIONAL,
   orientation              Wgs84Angle OPTIONAL,
   occupancyRule            ParkingOccupancyInfo, 
   chargingStationId        Identifier2B OPTIONAL,
   accessViaLane			Identifier2B OPTIONAL,
   accessViaParkingSpaces	SEQUENCE (SIZE(0..7)) OF Identifier2B OPTIONAL,	
   reservationType          SEQUENCE (SIZE(1..4,...)) OF ParkingReservationType OPTIONAL,			
   ...
}
```

### <a name="ParkingSpacesBasic"></a>ParkingSpacesBasic
This DF shall contain a list of ref @ParkingArea.
```asn1
ParkingSpacesBasic ::= SEQUENCE OF ParkingSpaceDetailed
```

### <a name="ParkingSpacesDetailed"></a>ParkingSpacesDetailed
This DF shall contain a list of ref @ParkingArea.
```asn1
ParkingSpacesDetailed ::= SEQUENCE OF ParkingSpaceDetailed
```

### <a name="ParkingSpaceStatus"></a>ParkingSpaceStatus
This DF indicates the status of parking space.

 The following options are available:

* _unknown_ of type **NULL** <br>
  indicates that the status is unknown.

* _free_ of type **NULL** <br>
  indicates that the parking space is free and hence available to be used.

* _freeUntil_ of type [**TimestampIts**](ETSI-ITS-CDD.md#TimestampIts) <br>
  indicates that the parking space is free to be used until an indicated moment in time.

* _fullyOccupied_ of type **NULL** <br>
  indicates that the parking space is interely occupied.

* _partiallyOccupied_ of type **INTEGER** (0..100)<br>
  indicates that the parking space that allows parking of multiple vehicles is occupied by an indicated percentage.

* _occupiedUntil_ of type [**TimestampIts**](ETSI-ITS-CDD.md#TimestampIts) <br>
  indicates that the parking space is entirely occupied until an indicated moment in time.

* _reservedUntil_ of type [**TimestampIts**](ETSI-ITS-CDD.md#TimestampIts) <br>
  indicates that the parking space is reserved (but not necessarily occupied) until an indicated moment in time.

* _accessBlocked_ of type **NULL** <br>
  indicates that the parking space cannot accessed, e.g. due to obstructing vehicles.

* _retrictedUsage_ of type **NULL** <br>
  indicates that the parking space is available but that it is not an official parking space and that there are some phyiscal restrictions applicable, 
   such as parking behind or in front of other vehicles that, depending on the situation, may then have problems entering or leaving their respective parking spaces.

```asn1
ParkingSpaceStatus::= CHOICE { 
   unknown             NULL, 
   free                NULL,  
   freeUntil           TimestampIts, 
   fullyOccupied       NULL,
   partiallyOccupied   INTEGER(0..100), 
   occupiedUntil       TimestampIts,
   reservedUntil       TimestampIts, 
   accessBlocked       NULL,
   retrictedUsage      NULL,
   ...
}
```

### <a name="ParkingStatus"></a>ParkingStatus
This DF provides information about the status of a defined type of parking.

 It shall include the following components:

* _vehicleTypes_ of type **SEQUENCE**  (SIZE(1..4,...)) OF EuVehicleCategoryCode OPTIONAL<br>
  the optional types of vehicle for which the parking status is provided.

* _reservationTypes_ of type **SEQUENCE**  (SIZE(1..4,...)) OF ParkingReservationType OPTIONAL<br>
  the optional reservation types for which the parking status is provided.

* _loadTypes_ of type **SEQUENCE**  (SIZE(1..4,...)) OF LoadType OPTIONAL<br>
  the optional load types for which the parking status is provided.

* _parkingFeeTypes_ of type **SEQUENCE**  (SIZE(1..4,...)) OF ParkingFeeType OPTIONAL<br>
  the optional fee types for which the parking status is provided.

* _occupancyTypes_ of type **SEQUENCE**  (SIZE(1..4,...)) OF ParkingOccupancyInfo OPTIONAL<br>
  the optional occupancy types for which the parking status is provided.

* _currentOccupancy_ of type [**OccupancyInformation**](#OccupancyInformation) <br>
  the occupancy for the logical AND combination of the components defined above.

```asn1
ParkingStatus ::= SEQUENCE {
   vehicleTypes            SEQUENCE (SIZE(1..4,...)) OF EuVehicleCategoryCode OPTIONAL,
   reservationTypes        SEQUENCE (SIZE(1..4,...)) OF ParkingReservationType OPTIONAL,
   loadTypes               SEQUENCE (SIZE(1..4,...)) OF LoadType OPTIONAL,
   parkingFeeTypes         SEQUENCE (SIZE(1..4,...)) OF ParkingFeeType OPTIONAL, 
   occupancyTypes          SEQUENCE (SIZE(1..4,...)) OF ParkingOccupancyInfo OPTIONAL,
   currentOccupancy        OccupancyInformation,
   ...
}
   ((WITH COMPONENTS {..., vehicleTypes PRESENT}) |
    (WITH COMPONENTS {..., reservationTypes PRESENT}) |
    (WITH COMPONENTS {..., loadTypes PRESENT}) | 
    (WITH COMPONENTS {..., parkingFeeTypes PRESENT}) |
    (WITH COMPONENTS {..., occupancyTypes PRESENT}))
```

### <a name="ParkingStatusList"></a>ParkingStatusList
This DF shall contain a list of [**ParkingStatus**](#ParkingStatus).
```asn1
ParkingStatusList::= SEQUENCE (SIZE(1..16,...)) OF ParkingStatus
```

### <a name="Period"></a>Period
This DF indicates a period occuring on defined days of the week.

 It shall include the following components:

* _days_ of type [**DayOfWeek**](#DayOfWeek) <br>
  the applicable day(s) of the week.

* _opening_ of type [**TimeOfDay**](#TimeOfDay) <br>
  the opening time in local time.

* _closing_ of type [**TimeOfDay**](#TimeOfDay) <br>
  the closing time in local time.

```asn1
Period ::= SEQUENCE {
    days      DayOfWeek,         
	opening	  TimeOfDay,	
	closing	  TimeOfDay 	
}
```

### <a name="Periods"></a>Periods
This DF shall contain a list of up to 8 [**Period**](#Period).
```asn1
Periods ::= SEQUENCE (SIZE(1..8,...)) OF Period
```

### <a name="TimeOfDay"></a>TimeOfDay
This DF indicates the time of the day.

 It shall include the following components:

* _hours_ of type **INTEGER**  (0..23)<br>
  the number of hours after midnight.

* _mins_ of type **INTEGER**  (0..59)<br>
  the number of minutes after the hour.

```asn1
TimeOfDay::= SEQUENCE {
   hours      INTEGER (0..23),
   mins       INTEGER (0..59) 
   }
```

### <a name="DayOfWeek"></a>DayOfWeek
This DE indicates the applicable day(s) of the week.
```asn1
DayOfWeek::= BIT STRING {unused(0), monday(1), tuesday(2), wednesday(3), thursday(4), friday(5), saturday(6), sunday(7)} (SIZE (8))
```

### <a name="GoodsType"></a>GoodsType
This DE indicates the type of goods of a vehicle.

 The value shall be set to:
 - `0` to indicate: 	Transport of ammunition.
 - `1` to indicate:	Transport of chemicals of unspecified type.
 - `2` to indicate: 	Empty load.
 - `3` to indicate: 	Transport of fuel of unspecified type.
 - `4` to indicate: 	Transport of glass.
 - `5` to indicate: 	Transport of materials classified as of dangerous or hazardous nature.
 - `6` to indicate: 	Transport of liquids of an unspecified nature.
 - `7` to indicate: 	Transport of livestock.
 - `8` to indicate: 	Transport of materials classed as being of a danger to people or animals.
 - `9` to indicate: 	Transport of materials classed as being potentially dangerous to the environment.
 - `10` to indicate: 	Transport of materials classed as being dangerous when exposed to water.
 - `11` to indicate: 	Transport of fresh products or produce that will significantly degrade in quality or freshness over a short period of time.
 - `12` to indicate: 	Transport of pharmaceutical materials.
 - `13` to indicate: 	Transport of vehicles of any type.
 - `14` to indicate: 	Refrigerated transport.

Values:
* **ammunition** (0)<br>
* **chemicals** (1)<br>
* **empty** (2)<br>
* **fuel** (3)<br>
* **glass** (4)<br>
* **dangerous** (5)<br>
* **liquid** (6)<br>
* **liveStock** (7)<br>
* **dangerousForPeople** (8)<br>
* **dangerousForTheEnvironment** (9)<br>
* **dangerousForWater** (10)<br>
* **perishableProducts** (11)<br>
* **pharmaceutical** (12)<br>
* **vehicles** (13)<br>
* **refrigerated** (14)<br>
* **--** other values  reserved for future use<br>
```asn1
GoodsType::= INTEGER {
	ammunition					(0),
	chemicals					(1),
	empty 						(2),
	fuel						(3),
	glass						(4),
	dangerous					(5),
	liquid						(6),
	liveStock					(7),
	dangerousForPeople			(8),
	dangerousForTheEnvironment	(9),
	dangerousForWater			(10),
	perishableProducts			(11),
	pharmaceutical				(12),
	vehicles					(13),
    refrigerated                (14)
	} (0..15,...)
```

### <a name="NumberOfSpaces"></a>NumberOfSpaces
This DE represents a number of parking spaces.
 
 The value shall be set to:
 - `n` (`n > 0` and `n < 16383`) : for the number of spaces.
 - `16383`                       : in case the number of spaces is not available.

Values:
* **unavailable** (101)<br>
```asn1
NumberOfSpaces ::= INTEGER {
    unavailable (101)  
} (1..16383)
```

### <a name="OccupancyRate"></a>OccupancyRate
This DE represents an occupancy rate in percentage.
 
 The value shall be set to:
 - `n` (`n > 0` and `n < 101`) : for the occupany rate in %,
 - `101`                   : in case the occupany rate is not available.

Values:
* **unavailable** (101)<br>
```asn1
OccupancyRate ::= INTEGER {
    unavailable (101)  
} (1..101)
```

### <a name="OccupancyTrend"></a>OccupancyTrend
This DE indicates the trend of occupancy.

 The value shall be set to:
 - `0` to indicate that occupancy is decreasing,
 - `1` to indicate that occupancy is decreasing quickly,
 - `2` to indicate that occupancy is decreasing slowly,
 - `3` to indicate that occupancy is increasing,
 - `4` to indicate that occupancy is increasing quickly,
 - `5` to indicate that occupancy is increasing slowly,
 - `6` to indicate that occupancy is stable,
 - `7` to indicate that occupancy is variable with no clear trend,
 - `15` to indicate that occupancy is unknown,
 - 8-14   - reserved for future usage.

Values:
* **decreasing** (0)<br>
* **decreasingQuickly** (1)<br>
* **decreasingSlowly** (2)<br>
* **increasing** (3)<br>
* **increasingQuickly** (4)<br>
* **increasingSlowly** (5)<br>
* **stable** (6)<br>
* **variable** (7)<br>
* **unknown** (15)<br>
```asn1
OccupancyTrend ::= INTEGER {
	decreasing				(0),
	decreasingQuickly		(1),
	decreasingSlowly		(2),
	increasing				(3),
    increasingQuickly       (4),
    increasingSlowly        (5),
    stable                  (6),
    variable                (7),
    unknown                 (15)
} (0..15)
```

### <a name="OpeningStatus"></a>OpeningStatus
This DE indicates the opening status.

 The value shall be set to:
 - `0` to indicate that the opening status is: closed,
 - `1` to indicate that the opening status is: open,
 - `2` to indicate that the opening status is: open for subscribers only,
 - `3` to indicate that the opening status is: open but currently full, i.e. no parking spaces available,
 - `15` to indicate that occupancy is: unknown,
 - 4-14 - reserved for future usage.

Values:
* **closed** (0)<br>
* **open** (1)<br>
* **subscribersOnly** (2)<br>
* **full** (3)<br>
* **unknown** (15)<br>
```asn1
OpeningStatus ::= INTEGER {
	closed				(0),
	open				(1),
	subscribersOnly		(2),
    full                (3),
	unknown				(15)
} (0..15)
```

### <a name="ParkingAreaArrangementType"></a>ParkingAreaArrangementType
This DE indicates the arrangement of parking space in a parking area.

 The value shall be set to:
 - `0` to indicate that the parking spaces are arranged in a line and parallel to a road or curb,
 - `1` to indicate that the parking spaces are arranged side-by-side and diagonally to a curb,
 - `2` to indicate that the parking spaces are arranged side-by-side and perpendicularly to a curb,
 - `3` to indicate that the parking spaces are arranged so that vehicles form a queue,
 - `4` to indicate that the parking spaces are arranged in a mixed fashion, 
 - 5-7 - reserved for future usage.

Values:
* **queueParking** (3)<br>
```asn1
ParkingAreaArrangementType ::= INTEGER { 
   parallelParkingSpace(0), 
   diagonalParkingSpace(1), 
   perpendicularParkingSpace(2),
   queueParking (3),
   mixed(4),
   unknown(7)   
} (0..7)
```

### <a name="ParkingReservationType"></a>ParkingReservationType
This DE indicates the type of a reservation of a parking space/area.

 The value shall be set to:
 - `0` to indicate that it is reserved to disabled persons,
 - `1` to indicate that it is reserved to pregnant women,
 - `2` to indicate that it is reserved to women,
 - `3` to indicate that it is reserved to parents with small children,
 - `4` to indicate that it is reserved for loading and unloading of goods,
 - `5` to indicate that it is reserved for manual charging of electric vehicles,
 - `6` to indicate that it is reserved for automated charging of electric vehicles,
 - `7` to indicate that it is reserved for vehicles carrying out refrigerated transport of goods,
 - `8` to indicate that it is reserved for VIPs,
 - `9` to indicate that it is reserved for pre-booked reservations only,
 - `10` to indicate that it is not reserved and can still be reserved,
 - `11` to indicate that it cannot be reserved,
 - `12` to indicate that it reserved for drop-off and pick-up of vehicles for automated valet parking,
 - `13` to indicate that it is reserved for vehicles with a permit,
 - 14-31  - reserved for future usage.

Values:
* **manualElectricVehicleCharging** (5)<br>
* **automatedElectricVehicleCharging** (6)<br>
* **preBooking** (9)<br>
* **freeToBeReserved** (10)<br>
* **reservationNotPossible** (11)<br>
* **automatedValetparking** (12)<br>
* **permit** (13)<br>
```asn1
ParkingReservationType ::= INTEGER { 
   disabled(0), 
   pregnant(1), 
   womenOnly(2), 
   parentAndChild(3), 
   loadAndOffloadGoods(4), 
   manualElectricVehicleCharging (5), 
   automatedElectricVehicleCharging (6), 
   refriferatedTransport(7),
   vip(8),
   preBooking (9), 
   freeToBeReserved (10),
   reservationNotPossible (11),
   automatedValetparking (12), 
   permit (13)
}(0..31)
```

### <a name="ParkingFeeType"></a>ParkingFeeType
This DE indicates the applicable type of parking fee.

 The value shall be set to:
 - `0` to indicate that the applicable fee is time dependent, e.g. an hourly fee,
 - `1` to indicate that ithe applicable fee is flat for a certain period, e.g. a flat fee for daily parking,
 - `2` to indicate that the applicable fee is included in the subscription, e.g. a monthly subscription,
 - 3-7  - reserved for future usage.
```asn1
ParkingFeeType::= INTEGER { 
   timeDependentFee(0), 
   flatFee(1), 
   subscription(2) 
}(0..7)
```



